﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using C1.Silverlight.Chart;

namespace DragDrop_GridData_ChartSeries
{
    public partial class MainPage : UserControl
    {
        C1.Silverlight.C1DragDropManager dragManager = new C1.Silverlight.C1DragDropManager();
        ObservableCollection<MyDataClass> dataList = new ObservableCollection<MyDataClass>();

        public MainPage()
        {
            InitializeComponent();

            SetupGrid();
            SetupChart();

            dragManager.RegisterDropTarget(c1Chart1, true);
            dragManager.RegisterDropTarget(c1DataGrid1, true);

            dragManager.DragDrop += new C1.Silverlight.DragDropEventHandler(dragManager_DragDrop);
        }

        void dragManager_DragDrop(object source, C1.Silverlight.DragDropEventArgs e)
        {
            // Add the Series for the field dragged on the Chart control
            if (e.DropTarget.GetType().Equals(typeof(C1.Silverlight.Chart.C1Chart)))
            {
                string draggedfield = (((C1.Silverlight.DataGrid.DataGridColumnHeaderPresenter)(e.DragSource)).Content as TextBlock).Text;

                var fieldValues = new List<double>();

                // Get the Series values from the ObservableCollection
                if (draggedfield == "UnitPrice")
                    fieldValues = (from val in dataList select val.UnitPrice).ToList();
                else
                    fieldValues = (from val in dataList select val.UnitsInStock).ToList();

                if (c1Chart1.Data.Children.Count == 1 && c1Chart1.Data.Children[0].Label == "dummy")
                    c1Chart1.Data.Children.Clear();

                // Check if series has already been added in Chart
                foreach (DataSeries ds in c1Chart1.Data.Children)
                    if (ds.Label == draggedfield)
                        return;

                // add series to the chart
                DataSeries ds1 = new DataSeries();
                ds1.Label = draggedfield;
                ds1.ValuesSource = fieldValues.ToList();
                ds1.PlotElementLoaded += new EventHandler(ds1_PlotElementLoaded);
                c1Chart1.Data.Children.Add(ds1);

                // Reset the Axis Min and Max as per 
                // the values of new DataSeries
                double fldMin = fieldValues.Min();
                if (fldMin < c1Chart1.View.AxisY.Min)
                    c1Chart1.View.AxisY.Min = fldMin;

                double fldMax = fieldValues.Max();
                if (fldMax > c1Chart1.View.AxisY.Max)
                    c1Chart1.View.AxisY.Max = fldMax;
            }
            // Remove the series for the Chart bar dragged on to the Grid 
            else
            {
                c1Chart1.Data.Children.Remove((e.DragSource as PlotElement).DataPoint.Series);
                if (c1Chart1.Data.Children.Count == 0)
                    SetupChart();
            }
        }

        /// <summary>
        /// Initial Grid settings
        /// </summary>
            public void SetupGrid()
            {
                dataList.Add(new MyDataClass() { ProductName = "Chai", UnitPrice = 18.00, UnitsInStock = 39.00 });
                dataList.Add(new MyDataClass() { ProductName = "Chang", UnitPrice = 19.00, UnitsInStock = 17.00 });
                dataList.Add(new MyDataClass() { ProductName = "Ikura", UnitPrice = 31.00, UnitsInStock = 31.00 });
                dataList.Add(new MyDataClass() { ProductName = "Pavlova", UnitPrice = 17.45, UnitsInStock = 29.00 });
                dataList.Add(new MyDataClass() { ProductName = "Tunnbröd", UnitPrice = 9.00, UnitsInStock = 61.00 });
                dataList.Add(new MyDataClass() { ProductName = "Gravad lax", UnitPrice = 26.00, UnitsInStock = 11.00 });
                dataList.Add(new MyDataClass() { ProductName = "Geitost", UnitPrice = 25.00, UnitsInStock = 50.00 });
                dataList.Add(new MyDataClass() { ProductName = "Chocolade", UnitPrice = 12.75, UnitsInStock = 15 });
                dataList.Add(new MyDataClass() { ProductName = "Pâté chinois", UnitPrice = 24.00, UnitsInStock = 30 });

                c1DataGrid1.ItemsSource = dataList;
                c1DataGrid1.LoadedColumnHeaderPresenter += new EventHandler<C1.Silverlight.DataGrid.DataGridColumnEventArgs>(c1DataGrid1_LoadedColumnHeaderPresenter);
            }

        /// <summary>
        /// Mark the Column Headers as Dragged Source object
        /// </summary>
        void c1DataGrid1_LoadedColumnHeaderPresenter(object sender, C1.Silverlight.DataGrid.DataGridColumnEventArgs e)
        {
            if (e.Column.Index > 0)
                dragManager.RegisterDragSource(e.Column.HeaderPresenter, C1.Silverlight.DragDropEffect.Copy, ModifierKeys.None);
        }

        /// <summary>
        /// Set the Chart settings
        /// </summary>
        public void SetupChart()
        {
            c1Chart1.Data.Children.Clear();

            var list = (from prod in dataList select prod.ProductName);

            c1Chart1.View.AxisY.Max = 10;
            c1Chart1.View.AxisY.AutoMax = false;
            c1Chart1.View.AxisY.Min = 0;
            c1Chart1.View.AxisY.AutoMin = false;

            c1Chart1.View.AxisX.AnnoAngle = 90;

            int[] PriceX = { 0, 0, 0, 0, 0, 0, 0, 0 };
            DataSeries ds1 = new DataSeries();
            ds1.Label = "dummy";
            //set price data
            ds1.ValuesSource = PriceX;

            // add series to the chart
            c1Chart1.Data.Children.Add(ds1);

            //// add item names
            c1Chart1.Data.ItemNames = list.ToArray();

            // Set chart type
            c1Chart1.ChartType = ChartType.Column;

        }

        /// <summary>
        /// Register Each Chart plot Element as Dragged Object
        /// Drag the Chart bars outside the chart to remove the series        
        void ds1_PlotElementLoaded(object sender, EventArgs e)
        {
            PlotElement pe = sender as PlotElement;
            dragManager.RegisterDragSource(pe, C1.Silverlight.DragDropEffect.Copy, ModifierKeys.None);
        }
    }

    public class MyDataClass
    {
        public string ProductName { get; set; }
        public double UnitPrice { get; set; }
        public double UnitsInStock { get; set; }
    }
}
